# Partner3DGeeksAlert

Do not use underscores in this serializer - linitation of Firebase Cloud Messaging

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**event** | **str** |  | [readonly] 
**token** | **str** |  | [readonly] 
**printer** | **str** |  | [readonly] 
**_print** | **str** |  | [readonly] 
**current_time** | **int** |  | [readonly] 
**time_left** | **int** |  | [readonly] 
**percent** | **int** |  | [readonly] 
**image** | **str** |  | [readonly] 
**action** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


